@@ -7,6 +7,18 @@ def data_entity_usage_request():
     return DataEntityUsageStatsRequest
 
 
+@pytest.fixture
+def query_builder():
+    from alvin_api_client.model.query_builder import QueryBuilder
+    return QueryBuilder
+
+
+@pytest.fixture
+def operator_type():
+    from alvin_api_client.model.operator_type import OperatorType
+    return OperatorType
+
+
 def test_data_entity_usage_request(
     data_entity_usage_request,
     query_builder,
